@@ -15,6 +15,9 @@ from .entity import (
     NodeInventory,
     RandomTemplateVariables,
     RecoverSetting,
+    SearchItem,
+    SearchRequest,
+    SearchResponse,
     TaskDeleteRequest,
     TaskDetail,
     TaskItem,
@@ -35,6 +38,9 @@ from .dto import (
     NodeInventoryDTO,
     RandomTemplateVariablesDTO,
     RecoverSettingDTO,
+    SearchItemDTO,
+    SearchRequestDTO,
+    SearchResponseDTO,
     TaskDeleteRequestDTO,
     TaskDetailDTO,
     TaskItemDTO,
@@ -428,3 +434,68 @@ class RecoverSettingAssembler(Assembler):
             dns_inventory = None if x.dns_inventory is None else [dns_inventory_assembler.to_dto(m) for m in x.dns_inventory]
         )
 recover_setting_assembler=RecoverSettingAssembler()
+
+
+
+class SearchRequestAssembler(Assembler):
+    def to_entity(self, dto: SearchRequestDTO):
+        return SearchRequest(
+            keyword = UStr(dto.keyword),
+            limit = UInt(dto.limit),
+            request_id = None if dto.request_id is None else UStr(dto.request_id),
+            others = None if dto.others is None else UDict(dto.others)
+        )
+    def to_dto(self, x:SearchRequest):
+        return SearchRequestDTO(
+            keyword = x.keyword.get_value(),
+            limit = x.limit.get_value(),
+            request_id = None if x.request_id is None else x.request_id.get_value(),
+            others = None if x.others is None else x.others.get_value()
+        )
+search_request_assembler=SearchRequestAssembler()
+
+
+
+class SearchResponseAssembler(Assembler):
+    def to_entity(self, dto: SearchResponseDTO):
+        return SearchResponse(
+            status = Status(dto.status),
+            exception = None if dto.exception is None else UStr(dto.exception),
+            result = None if dto.result is None else UDict(dto.result),
+            others = None if dto.others is None else UDict(dto.others)
+        )
+    def to_dto(self, x:SearchResponse):
+        return SearchResponseDTO(
+            status = x.status.get_value(),
+            exception = None if x.exception is None else x.exception.get_value(),
+            result = None if x.result is None else x.result.get_value(),
+            others = None if x.others is None else x.others.get_value()
+        )
+search_response_assembler=SearchResponseAssembler()
+
+
+
+class SearchItemAssembler(Assembler):
+    def to_entity(self, dto: SearchItemDTO):
+        return SearchItem(
+            item_id = UStr(dto.item_id),
+            status = Status(dto.status),
+            exception = None if dto.exception is None else UStr(dto.exception),
+            request = None if dto.request is None else search_request_assembler.to_entity(dto.request),
+            response = None if dto.response is None else search_response_assembler.to_entity(dto.response),
+            entry_time = None if dto.entry_time is None else UDate(dto.entry_time),
+            exit_time = None if dto.exit_time is None else UDate(dto.exit_time),
+            create_time = None if dto.create_time is None else UDate(dto.create_time)
+        )
+    def to_dto(self, x:SearchItem):
+        return SearchItemDTO(
+            item_id = x.item_id.get_value(),
+            status = x.status.get_value(),
+            exception = None if x.exception is None else x.exception.get_value(),
+            request = None if x.request is None else search_request_assembler.to_dto(x.request),
+            response = None if x.response is None else search_response_assembler.to_dto(x.response),
+            entry_time = None if x.entry_time is None else x.entry_time.get_value(),
+            exit_time = None if x.exit_time is None else x.exit_time.get_value(),
+            create_time = None if x.create_time is None else x.create_time.get_value()
+        )
+search_item_assembler=SearchItemAssembler()
