@@ -15,6 +15,9 @@ from .entity import (
     NodeInventory,
     RandomTemplateVariables,
     RecoverSetting,
+    SearchItem,
+    SearchRequest,
+    SearchResponse,
     TaskDeleteRequest,
     TaskDetail,
     TaskItem,
@@ -35,6 +38,9 @@ from .do import (
     NodeInventoryDO,
     RandomTemplateVariablesDO,
     RecoverSettingDO,
+    SearchItemDO,
+    SearchRequestDO,
+    SearchResponseDO,
     TaskDeleteRequestDO,
     TaskDetailDO,
     TaskItemDO,
@@ -428,3 +434,68 @@ class RecoverSettingConverter(Converter):
             dns_inventory = None if x.dns_inventory is None else [dns_inventory_converter.to_do(m) for m in x.dns_inventory]
         )
 recover_setting_converter=RecoverSettingConverter()
+
+
+
+class SearchRequestConverter(Converter):
+    def to_entity(self, do: SearchRequestDO):
+        return SearchRequest(
+            keyword = UStr(do.keyword),
+            limit = UInt(do.limit),
+            request_id = None if do.request_id is None else UStr(do.request_id),
+            others = None if do.others is None else UDict(do.others)
+        )
+    def to_do(self, x:SearchRequest):
+        return SearchRequestDO(
+            keyword = x.keyword.get_value(),
+            limit = x.limit.get_value(),
+            request_id = None if x.request_id is None else x.request_id.get_value(),
+            others = None if x.others is None else x.others.get_value()
+        )
+search_request_converter=SearchRequestConverter()
+
+
+
+class SearchResponseConverter(Converter):
+    def to_entity(self, do: SearchResponseDO):
+        return SearchResponse(
+            status = Status(do.status),
+            exception = None if do.exception is None else UStr(do.exception),
+            result = None if do.result is None else UDict(do.result),
+            others = None if do.others is None else UDict(do.others)
+        )
+    def to_do(self, x:SearchResponse):
+        return SearchResponseDO(
+            status = x.status.get_value(),
+            exception = None if x.exception is None else x.exception.get_value(),
+            result = None if x.result is None else x.result.get_value(),
+            others = None if x.others is None else x.others.get_value()
+        )
+search_response_converter=SearchResponseConverter()
+
+
+
+class SearchItemConverter(Converter):
+    def to_entity(self, do: SearchItemDO):
+        return SearchItem(
+            item_id = UStr(do.item_id),
+            status = Status(do.status),
+            exception = None if do.exception is None else UStr(do.exception),
+            request = None if do.request is None else search_request_converter.to_entity(do.request),
+            response = None if do.response is None else search_response_converter.to_entity(do.response),
+            entry_time = None if do.entry_time is None else UDate(do.entry_time),
+            exit_time = None if do.exit_time is None else UDate(do.exit_time),
+            create_time = None if do.create_time is None else UDate(do.create_time)
+        )
+    def to_do(self, x:SearchItem):
+        return SearchItemDO(
+            item_id = x.item_id.get_value(),
+            status = x.status.get_value(),
+            exception = None if x.exception is None else x.exception.get_value(),
+            request = None if x.request is None else search_request_converter.to_do(x.request),
+            response = None if x.response is None else search_response_converter.to_do(x.response),
+            entry_time = None if x.entry_time is None else x.entry_time.get_value(),
+            exit_time = None if x.exit_time is None else x.exit_time.get_value(),
+            create_time = None if x.create_time is None else x.create_time.get_value()
+        )
+search_item_converter=SearchItemConverter()
