@@ -163,4 +163,32 @@ class DNSInventoryDTO(BaseModel):
 
 class RecoverSettingDTO(BaseModel):
     node_inventory: Optional[List[NodeInventoryDTO]]
-    dns_inventory: Optional[List[DNSInventoryDTO]]
\ No newline at end of file
+    dns_inventory: Optional[List[DNSInventoryDTO]]
+
+
+
+class SearchRequestDTO(BaseModel):
+    keyword: str
+    limit: int = 5
+    request_id: Optional[str] = None
+    others: Optional[dict] = None
+
+
+
+class SearchResponseDTO(BaseModel):
+    status: str
+    exception: Optional[str] = None
+    result: Optional[dict] = None
+    others: Optional[dict] = None
+
+
+
+class SearchItemDTO(BaseModel):
+    item_id: str
+    status: str
+    exception: Optional[str] = None
+    request: Optional[SearchRequestDTO] = None
+    response: Optional[SearchResponseDTO] = None
+    entry_time: Optional[datetime.datetime] = None
+    exit_time: Optional[datetime.datetime] = None
+    create_time: Optional[datetime.datetime] = None
\ No newline at end of file
