@@ -424,4 +424,75 @@ class RecoverSetting(Entity):
         del all_args['kwargs']
         super().__init__(**all_args)
         self.node_inventory = node_inventory
-        self.dns_inventory = dns_inventory
\ No newline at end of file
+        self.dns_inventory = dns_inventory
+
+
+
+class SearchRequest(Entity):
+    def __init__(
+        self,
+        keyword: UStr,
+        limit: UInt = 5,
+        request_id: Optional[UStr] = None,
+        others: Optional[UDict] = None,
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.keyword = keyword
+        self.limit = limit
+        self.request_id = request_id
+        self.others = others
+
+
+
+class SearchResponse(Entity):
+    def __init__(
+        self,
+        status: Status,
+        exception: Optional[UStr] = None,
+        result: Optional[UDict] = None,
+        others: Optional[UDict] = None,
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.status = status
+        self.exception = exception
+        self.result = result
+        self.others = others
+
+
+
+class SearchItem(Entity):
+    def __init__(
+        self,
+        item_id: UStr,
+        status: Status,
+        exception: Optional[UStr] = None,
+        request: Optional[SearchRequest] = None,
+        response: Optional[SearchResponse] = None,
+        entry_time: Optional[UDate] = None,
+        exit_time: Optional[UDate] = None,
+        create_time: Optional[UDate] = None,
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.item_id = item_id
+        self.status = status
+        self.exception = exception
+        self.request = request
+        self.response = response
+        self.entry_time = entry_time
+        self.exit_time = exit_time
+        self.create_time = create_time
\ No newline at end of file
